/**
Check if the process is running inside a container.

@example
```
import isInsideContainer from 'is-inside-container';

if (isInsideContainer()) {
	console.log('Running inside a container');
}
```
*/
export default function isInsideContainer(): boolean;
