/**
Check if the process is running inside a Docker container.

@example
```
import isDocker from 'is-docker';

if (isDocker()) {
	console.log('Running inside a Docker container');
}
```
*/
export default function isDocker(): boolean;
